"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Logs in the user using given credentials
 */
exports.loginUser = (credentials) => (page) => __awaiter(void 0, void 0, void 0, function* () {
    const { email, password } = credentials;
    const selectors = {
        emailInput: 'input#email',
        passwordInput: 'input#pass',
        loginSubmitButton: 'label#loginbutton',
    };
    /* Enter email */
    yield page.focus(selectors.emailInput);
    yield page.keyboard.type(email);
    /* Enter password */
    yield page.focus(selectors.passwordInput);
    yield page.keyboard.type(password);
    /* Submit login form */
    yield Promise.all([
        page.waitForNavigation(),
        page.click(selectors.loginSubmitButton),
    ]);
});
/**
 * Navigates from the Home page to the Profile page
 */
exports.navigateToProfile = (page) => __awaiter(void 0, void 0, void 0, function* () {
    const selectors = {
        profileButton: 'a[title="Profile"]',
    };
    /* Click on profile button */
    yield page.waitForSelector(selectors.profileButton);
    yield page.click(selectors.profileButton);
    yield page.waitFor(2500);
});
/**
 * Navigates from the Profile page to the Activity Log page
 */
exports.navigateToActivityLog = (page) => __awaiter(void 0, void 0, void 0, function* () {
    const selectors = {
        activityLogButton: "//a[contains(., 'Activity log')] | //a[contains(., 'Activity Log')]",
    };
    /* Click on activity log button */
    yield page.waitForXPath(selectors.activityLogButton);
    const [activityLogButton] = yield page.$x(selectors.activityLogButton);
    yield activityLogButton.click();
    yield page.waitFor(2500);
});
/**
 * Selects a filter on the Activity Log page
 */
exports.selectActivityLogFilter = (filter) => (page) => __awaiter(void 0, void 0, void 0, function* () {
    /* TODO: Activate filter argument */
    const selectors = {
        filterByPostsButton: 'a[title="Posts"]',
    };
    /* Select posts activity log */
    yield page.waitForSelector(selectors.filterByPostsButton);
    yield page.click(selectors.filterByPostsButton);
    yield page.waitFor(2500);
});
/**
 * Deletes the latest post on the Posts Activity Log page
 */
exports.deleteLatestPost = (page) => __awaiter(void 0, void 0, void 0, function* () {
    const selectors = {
        optionsButton: 'a[aria-label="Edit"]',
        deleteOptionButton: "//a[contains(., 'Delete')]",
        deleteSubmitButton: "//button[contains(., 'Delete')]",
    };
    /* Click on activity log item options */
    yield page.waitForSelector(selectors.optionsButton);
    yield page.evaluate(selector => document.querySelector(selector).click(), selectors.optionsButton);
    yield page.waitFor(2500);
    /* Click on activity log item delete option */
    yield page.waitForXPath(selectors.deleteOptionButton);
    const [deleteOptionButton] = yield page.$x(selectors.deleteOptionButton);
    yield deleteOptionButton.click();
    yield page.waitFor(2500);
    /* Click on deletion prompt submit button */
    yield page.waitForXPath(selectors.deleteSubmitButton);
    const [deleteSubmitButton] = yield page.$x(selectors.deleteSubmitButton);
    yield deleteSubmitButton.click();
    yield page.waitFor(2500);
});
//# sourceMappingURL=facebook.js.map